@@ -60,12 +60,12 @@ new Assignment(this, 'ExampleAssignment', {
 });
 
 // assign it to something else with a grant
-permissionSetExample.grant(
-  {
+permissionSetExample.grant('permissionSetExampleAssignment',
+  principal: {
     principalId: '12350630-0ae9-479a-97c2-0afc2d5b4eac',
     principalType: PrincipalTypes.GROUP,
   },
-  '344567890123456',
+  targetId: '344567890123456',
 );
 
 // import an existing permission set
@@ -115,27 +115,24 @@ class AssignmentAttributes:
 
 
 @jsii.data_type(
-    jsii_type="@renovosolutions/cdk-library-aws-sso.AssignmentProps",
+    jsii_type="@renovosolutions/cdk-library-aws-sso.AssignmentOptions",
     jsii_struct_bases=[],
     name_mapping={
-        "permission_set": "permissionSet",
         "principal": "principal",
         "target_id": "targetId",
         "target_type": "targetType",
     },
 )
-class AssignmentProps:
+class AssignmentOptions:
     def __init__(
         self,
         *,
-        permission_set: "IPermissionSet",
         principal: typing.Union["PrincipalProperty", typing.Dict[str, typing.Any]],
         target_id: builtins.str,
         target_type: typing.Optional["TargetTypes"] = None,
     ) -> None:
-        '''The properties of a new assignment.
+        '''The options for creating an assignment.
 
-        :param permission_set: The permission set to assign to the principal.
         :param principal: The principal to assign the permission set to.
         :param target_id: The target id the permission set will be assigned to.
         :param target_type: The entity type for which the assignment will be created. Default: TargetTypes.AWS_ACCOUNT
@@ -143,26 +140,17 @@ class AssignmentProps:
         if isinstance(principal, dict):
             principal = PrincipalProperty(**principal)
         if __debug__:
-            type_hints = typing.get_type_hints(AssignmentProps.__init__)
-            check_type(argname="argument permission_set", value=permission_set, expected_type=type_hints["permission_set"])
+            type_hints = typing.get_type_hints(AssignmentOptions.__init__)
             check_type(argname="argument principal", value=principal, expected_type=type_hints["principal"])
             check_type(argname="argument target_id", value=target_id, expected_type=type_hints["target_id"])
             check_type(argname="argument target_type", value=target_type, expected_type=type_hints["target_type"])
         self._values: typing.Dict[str, typing.Any] = {
-            "permission_set": permission_set,
             "principal": principal,
             "target_id": target_id,
         }
         if target_type is not None:
             self._values["target_type"] = target_type
 
-    @builtins.property
-    def permission_set(self) -> "IPermissionSet":
-        '''The permission set to assign to the principal.'''
-        result = self._values.get("permission_set")
-        assert result is not None, "Required property 'permission_set' is missing"
-        return typing.cast("IPermissionSet", result)
-
     @builtins.property
     def principal(self) -> "PrincipalProperty":
         '''The principal to assign the permission set to.'''
@@ -192,6 +180,90 @@ class AssignmentProps:
     def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
+    def __repr__(self) -> str:
+        return "AssignmentOptions(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
+@jsii.data_type(
+    jsii_type="@renovosolutions/cdk-library-aws-sso.AssignmentProps",
+    jsii_struct_bases=[AssignmentOptions],
+    name_mapping={
+        "principal": "principal",
+        "target_id": "targetId",
+        "target_type": "targetType",
+        "permission_set": "permissionSet",
+    },
+)
+class AssignmentProps(AssignmentOptions):
+    def __init__(
+        self,
+        *,
+        principal: typing.Union["PrincipalProperty", typing.Dict[str, typing.Any]],
+        target_id: builtins.str,
+        target_type: typing.Optional["TargetTypes"] = None,
+        permission_set: "IPermissionSet",
+    ) -> None:
+        '''The properties of a new assignment.
+
+        :param principal: The principal to assign the permission set to.
+        :param target_id: The target id the permission set will be assigned to.
+        :param target_type: The entity type for which the assignment will be created. Default: TargetTypes.AWS_ACCOUNT
+        :param permission_set: The permission set to assign to the principal.
+        '''
+        if isinstance(principal, dict):
+            principal = PrincipalProperty(**principal)
+        if __debug__:
+            type_hints = typing.get_type_hints(AssignmentProps.__init__)
+            check_type(argname="argument principal", value=principal, expected_type=type_hints["principal"])
+            check_type(argname="argument target_id", value=target_id, expected_type=type_hints["target_id"])
+            check_type(argname="argument target_type", value=target_type, expected_type=type_hints["target_type"])
+            check_type(argname="argument permission_set", value=permission_set, expected_type=type_hints["permission_set"])
+        self._values: typing.Dict[str, typing.Any] = {
+            "principal": principal,
+            "target_id": target_id,
+            "permission_set": permission_set,
+        }
+        if target_type is not None:
+            self._values["target_type"] = target_type
+
+    @builtins.property
+    def principal(self) -> "PrincipalProperty":
+        '''The principal to assign the permission set to.'''
+        result = self._values.get("principal")
+        assert result is not None, "Required property 'principal' is missing"
+        return typing.cast("PrincipalProperty", result)
+
+    @builtins.property
+    def target_id(self) -> builtins.str:
+        '''The target id the permission set will be assigned to.'''
+        result = self._values.get("target_id")
+        assert result is not None, "Required property 'target_id' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def target_type(self) -> typing.Optional["TargetTypes"]:
+        '''The entity type for which the assignment will be created.
+
+        :default: TargetTypes.AWS_ACCOUNT
+        '''
+        result = self._values.get("target_type")
+        return typing.cast(typing.Optional["TargetTypes"], result)
+
+    @builtins.property
+    def permission_set(self) -> "IPermissionSet":
+        '''The permission set to assign to the principal.'''
+        result = self._values.get("permission_set")
+        assert result is not None, "Required property 'permission_set' is missing"
+        return typing.cast("IPermissionSet", result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
     def __repr__(self) -> str:
         return "AssignmentProps(%s)" % ", ".join(
             k + "=" + repr(v) for k, v in self._values.items()
@@ -309,15 +381,18 @@ class IPermissionSet(aws_cdk.IResource, typing_extensions.Protocol):
     @jsii.member(jsii_name="grant")
     def grant(
         self,
+        id: builtins.str,
+        *,
         principal: typing.Union["PrincipalProperty", typing.Dict[str, typing.Any]],
         target_id: builtins.str,
         target_type: typing.Optional["TargetTypes"] = None,
     ) -> "Assignment":
         '''Grant this permission set to a given principal for a given targetId (AWS account identifier) on a given SSO instance.
 
-        :param principal: -
-        :param target_id: -
-        :param target_type: -
+        :param id: -
+        :param principal: The principal to assign the permission set to.
+        :param target_id: The target id the permission set will be assigned to.
+        :param target_type: The entity type for which the assignment will be created. Default: TargetTypes.AWS_ACCOUNT
         '''
         ...
 
@@ -350,22 +425,27 @@ class _IPermissionSetProxy(
     @jsii.member(jsii_name="grant")
     def grant(
         self,
+        id: builtins.str,
+        *,
         principal: typing.Union["PrincipalProperty", typing.Dict[str, typing.Any]],
         target_id: builtins.str,
         target_type: typing.Optional["TargetTypes"] = None,
     ) -> "Assignment":
         '''Grant this permission set to a given principal for a given targetId (AWS account identifier) on a given SSO instance.
 
-        :param principal: -
-        :param target_id: -
-        :param target_type: -
+        :param id: -
+        :param principal: The principal to assign the permission set to.
+        :param target_id: The target id the permission set will be assigned to.
+        :param target_type: The entity type for which the assignment will be created. Default: TargetTypes.AWS_ACCOUNT
         '''
         if __debug__:
             type_hints = typing.get_type_hints(IPermissionSet.grant)
-            check_type(argname="argument principal", value=principal, expected_type=type_hints["principal"])
-            check_type(argname="argument target_id", value=target_id, expected_type=type_hints["target_id"])
-            check_type(argname="argument target_type", value=target_type, expected_type=type_hints["target_type"])
-        return typing.cast("Assignment", jsii.invoke(self, "grant", [principal, target_id, target_type]))
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+        assignment_options = AssignmentOptions(
+            principal=principal, target_id=target_id, target_type=target_type
+        )
+
+        return typing.cast("Assignment", jsii.invoke(self, "grant", [id, assignment_options]))
 
 # Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
 typing.cast(typing.Any, IPermissionSet).__jsii_proxy_class__ = lambda : _IPermissionSetProxy
@@ -508,22 +588,27 @@ class PermissionSet(
     @jsii.member(jsii_name="grant")
     def grant(
         self,
+        id: builtins.str,
+        *,
         principal: typing.Union["PrincipalProperty", typing.Dict[str, typing.Any]],
         target_id: builtins.str,
         target_type: typing.Optional["TargetTypes"] = None,
     ) -> "Assignment":
         '''Grant this permission set to a given principal for a given targetId (AWS account identifier) on a given SSO instance.
 
-        :param principal: -
-        :param target_id: -
-        :param target_type: -
+        :param id: -
+        :param principal: The principal to assign the permission set to.
+        :param target_id: The target id the permission set will be assigned to.
+        :param target_type: The entity type for which the assignment will be created. Default: TargetTypes.AWS_ACCOUNT
         '''
         if __debug__:
             type_hints = typing.get_type_hints(PermissionSet.grant)
-            check_type(argname="argument principal", value=principal, expected_type=type_hints["principal"])
-            check_type(argname="argument target_id", value=target_id, expected_type=type_hints["target_id"])
-            check_type(argname="argument target_type", value=target_type, expected_type=type_hints["target_type"])
-        return typing.cast("Assignment", jsii.invoke(self, "grant", [principal, target_id, target_type]))
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+        assignment_options = AssignmentOptions(
+            principal=principal, target_id=target_id, target_type=target_type
+        )
+
+        return typing.cast("Assignment", jsii.invoke(self, "grant", [id, assignment_options]))
 
     @builtins.property
     @jsii.member(jsii_name="cfnPermissionSet")
@@ -901,6 +986,7 @@ class Assignment(
 __all__ = [
     "Assignment",
     "AssignmentAttributes",
+    "AssignmentOptions",
     "AssignmentProps",
     "CustomerManagedPolicyReference",
     "IAssignment",
